import { useEffect, useRef } from 'react';

/**
 * 运行一个函数，在每次重绘之前调用它。
 * @params {(deltaTime: number) => void )} callback
 */
var useRequestAnimationFrame = function useRequestAnimationFrame(callback) {
  var requestRef = useRef();
  var previousTimeRef = useRef();
  useEffect(function () {
    var animate = function animate(time) {
      if (previousTimeRef.current) {
        callback(time - previousTimeRef.current); //大约16.7ms
      }

      previousTimeRef.current = time;
      requestRef.current = requestAnimationFrame(animate);
    };
    requestRef.current = requestAnimationFrame(animate);
    return function () {
      return cancelAnimationFrame(requestRef.current);
    };
  }, []);
};
export default useRequestAnimationFrame;