import { cloneDeep } from 'lodash-es';
import { useCallback, useImperativeHandle, useRef } from 'react';

/**useShow 的实例 (包含一些方法) */

/**useShow 的配置项 */

/**用于在子组件 props 的 'funcRef' 的类型*/

/**
 * 父调用子组件方法，并传值更新状态
 * @param funcRef ref对象
 * @param options { onShow, onFormart, onHide }
 * @returns T 传输的数据
 */
export default function useShow(funcRef, options) {
  var ref = useRef();
  var childrenDataRef = useRef();
  var opsOnShow = options.onShow,
    opsOnFormart = options.onFormart,
    opsOnHide = options.onHide;
  useImperativeHandle(funcRef, function () {
    return {
      onShow: function onShow(data) {
        ref.current = cloneDeep(data);
        if (opsOnShow) opsOnShow(ref.current);
      },
      onHide: function onHide(data) {
        if (opsOnHide) opsOnHide(cloneDeep(data));
      },
      getChildData: function getChildData() {
        return childrenDataRef.current;
      }
    };
  });
  var onCallback = useCallback(function (data) {
    childrenDataRef.current = data;
  }, []);
  return {
    parentData: opsOnFormart ? opsOnFormart(ref.current) : ref.current,
    setParentData: onCallback
  };
}